=========================
collective.js.tooltipster
=========================
   
Plone integration of Tooltipster (http://iamceege.github.io/tooltipster/)

Version 4.2.6

Themes
****** 
If you want to use additional themes, just import profile "collective.js.tooltipster Themes" in portal_setup.

Following themes are available :

- tooltipster-light
- tooltipster-noir
- tooltipster-punk
- tooltipster-shadow
